@@ -258,13 +258,17 @@ class LayerView(APIView):
         map_structure = deepcopy(layer_structure["map"])
         background_styles = map_structure.get("backgroundStyle", [])
 
-        if type(background_styles) is list:
-            background_styles += baselayers
-        else:
-            # backgroundStyles can be just an url
-            baselayers.append({"label": "terra_default", "url": background_styles})
-            background_styles = baselayers
-        layer_structure["map"]["backgroundStyle"] = background_styles
+        # If no base layer, we use default one
+        if not baselayers:
+            if type(background_styles) is list:
+                # background_styles += baselayers
+                baselayers = background_styles
+            else:
+                # backgroundStyles can be just an url
+                baselayers = [{"label": "", "url": background_styles}]
+
+        layer_structure["map"]["backgroundStyle"] = baselayers
+
         return layer_structure
 
     def get_map_layers(self):
@@ -483,7 +487,7 @@ class LayerView(APIView):
     def get_filter_forms_for_layer(self, layer):
         """Return forms of a layer if filters are enabled"""
         if layer.filters_enabled:
-            return [
+            filter_list = [
                 {
                     "property": field_filter.field.name,
                     "label": field_filter.label or field_filter.field.label,
@@ -491,6 +495,9 @@ class LayerView(APIView):
                 }
                 for field_filter in layer.filters_enabled
             ]
+            # Respect filter defined order
+            filter_list.sort(key=lambda f: f.get("order", 0))
+            return filter_list
 
     @cached_property
     def authorized_sources(self):
